@@ -45,6 +45,10 @@ def asana_list_todos(workspace_name,filtering):
     if filtering == 'all':
         print(df)
         
+    if filtering == 'everyone':
+        df = asana_get_todos(workspace_name,filtering)
+        print(df)
+        
 def asana_get_todos(workspace_name,filtering):
      # read api key from ~/.dt_config.json
     client = get_client()
@@ -60,8 +64,13 @@ def asana_get_todos(workspace_name,filtering):
     # logging.basicConfig(level=logging.DEBUG)
 
     opt_fields='name,due_on,completed,projects,notes'
-    tasks = list(client.tasks.find_all({"opt_fields":opt_fields}, 
-                                       workspace=workspace_id, assignee='me'))
+    if filtering!='everyone':
+        tasks = list(client.tasks.find_all({"opt_fields":opt_fields}, 
+                                           workspace=workspace_id, assignee='me'))
+    else:
+        project_id = list(client.projects.get_projects_for_workspace(workspace_id))[0]['gid']
+        tasks = list(client.tasks.find_all({"opt_fields":opt_fields, "project_id": project_id}, 
+                                           project=project_id))
     df = pd.DataFrame(tasks)
     return df
     
@@ -92,13 +101,16 @@ def add_todo(task_text, expected_duration, project_id=0):
         # 'projects': [workspace_id]
     }
     
+    print(posting, data)
     result = client.tasks.create_in_workspace(workspace_id, data)
 
     print(json.dumps(result, indent=4))
     
-def done_todo():
-    pass
-
+def done_todo(task_id):
+    client = get_client()
+    data =  {'completed': True}
+    result = client.tasks.update_task(task_id, data)
+    print(json.dumps(result, indent=4))
 
 def fix_past_due(workspace_name):
     df = asana_get_todos(workspace_name,None)
